@@ -28,7 +28,7 @@
 #include "textbrowser_p.h"
 
 #include "editor/im/improtocols.h"
-
+#include <KIOCore/kio/transferjob.h>
 #include <collection.h>
 #include <collectionfetchjob.h>
 #include <entitydisplayattribute.h>
@@ -50,19 +50,19 @@
 
 using namespace Akonadi;
 
-class ContactViewer::Private
+class Q_DECL_HIDDEN ContactViewer::Private
 {
 public:
     Private(ContactViewer *parent)
         : mParent(parent)
+        , mBrowser(Q_NULLPTR)
         , mParentCollectionFetchJob(0)
     {
         mStandardContactFormatter = new StandardContactFormatter;
         mContactFormatter = mStandardContactFormatter;
 #ifdef HAVE_PRISON
-        //LAurent workaround for bug 352044 not commit in master. We are a new version of libprison
-        //mQRCode = new prison::QRCodeBarcode();
-        //mDataMatrix = new prison::DataMatrixBarcode();
+        mQRCode = new prison::QRCodeBarcode();
+        mDataMatrix = new prison::DataMatrixBarcode();
 #endif // HAVE_PRISON
     }
 
@@ -70,8 +70,8 @@ public:
     {
         delete mStandardContactFormatter;
 #ifdef HAVE_PRISON
-        //delete mQRCode;
-        //delete mDataMatrix;
+        delete mQRCode;
+        delete mDataMatrix;
 #endif // HAVE_PRISON
     }
 
@@ -85,12 +85,32 @@ public:
 
         if (mCurrentContact.photo().isIntern()) {
             mBrowser->document()->addResource(QTextDocument::ImageResource,
-                                              QUrl(QLatin1String("contact_photo")),
+                                              QUrl(QStringLiteral("contact_photo")),
                                               mCurrentContact.photo().data());
         } else if (!mCurrentContact.photo().url().isEmpty()) {
-            mBrowser->document()->addResource(QTextDocument::ImageResource,
-                                              QUrl(QStringLiteral("contact_photo")),
-                                              defaultPixmap);
+            QByteArray imageData;
+            QImage image;
+            KIO::TransferJob *job = KIO::get(QUrl(mCurrentContact.photo().url()), KIO::NoReload);
+            QObject::connect(job, &KIO::TransferJob::data,
+                             [&imageData](KIO::Job *, const QByteArray &data) {
+                                imageData.append(data);
+                             });
+            if (job->exec()) {
+                if (image.loadFromData(imageData)) {
+                    mBrowser->document()->addResource(QTextDocument::ImageResource,
+                                                      QUrl(QStringLiteral("contact_photo")),
+                                                      image);
+                } else {
+                    mBrowser->document()->addResource(QTextDocument::ImageResource,
+                                                      QUrl(QStringLiteral("contact_photo")),
+                                                      defaultPixmap);
+                }
+            } else {
+                mBrowser->document()->addResource(QTextDocument::ImageResource,
+                                                  QUrl(QStringLiteral("contact_photo")),
+                                                  defaultPixmap);
+
+            }
         } else {
             mBrowser->document()->addResource(QTextDocument::ImageResource,
                                               QUrl(QStringLiteral("contact_photo")),
@@ -102,7 +122,20 @@ public:
                                               QUrl(QStringLiteral("contact_logo")),
                                               mCurrentContact.logo().data());
         } else if (!mCurrentContact.logo().url().isEmpty()) {
-            //TODO
+            QByteArray imageData;
+            QImage image;
+            KIO::TransferJob *job = KIO::get(QUrl(mCurrentContact.logo().url()), KIO::NoReload);
+            QObject::connect(job, &KIO::TransferJob::data,
+                             [&imageData](KIO::Job *, const QByteArray &data) {
+                                imageData.append(data);
+                             });
+            if (job->exec()) {
+                if (image.loadFromData(imageData)) {
+                    mBrowser->document()->addResource(QTextDocument::ImageResource,
+                                                      QUrl(QStringLiteral("contact_logo")),
+                                                      image);
+                }
+            }
         }
 
         mBrowser->document()->addResource(QTextDocument::ImageResource,
@@ -114,12 +147,9 @@ public:
                                           defaultSmsPixmap);
 
 #ifdef HAVE_PRISON
-        KConfig config(QLatin1String("akonadi_contactrc"));
-        KConfigGroup group(&config, QLatin1String("View"));
+        KConfig config(QStringLiteral("akonadi_contactrc"));
+        KConfigGroup group(&config, QStringLiteral("View"));
         if (group.readEntry("QRCodes", true)) {
-            //Laurent workaround for 352044
-            prison::QRCodeBarcode *mQRCode = new prison::QRCodeBarcode();
-            prison::DataMatrixBarcode *mDataMatrix = new prison::DataMatrixBarcode();
             KContacts::VCardConverter converter;
             KContacts::Addressee addr(mCurrentContact);
             addr.setPhoto(KContacts::Picture());
@@ -146,15 +176,15 @@ public:
 
         foreach (const CustomField &field, globalCustomFields) {
             QVariantMap description;
-            description.insert(QLatin1String("key"), field.key());
-            description.insert(QLatin1String("title"), field.title());
+            description.insert(QStringLiteral("key"), field.key());
+            description.insert(QStringLiteral("title"), field.title());
 
             customFieldDescriptions << description;
         }
 
         KContacts::Addressee contact(mCurrentContact);
         if (!addressBookName.isEmpty()) {
-            contact.insertCustom(QLatin1String("KADDRESSBOOK"), QLatin1String("AddressBook"), addressBookName);
+            contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("AddressBook"), addressBookName);
         }
 
         mContactFormatter->setContact(contact);
@@ -180,21 +210,21 @@ public:
                 urlScheme == QLatin1String("https")) {
             emit mParent->urlClicked(url);
         } else if (urlScheme == QLatin1String("phone")) {
-            const int pos = url.queryItemValue(QLatin1String("index")).toInt();
+            const int pos = url.queryItemValue(QStringLiteral("index")).toInt();
 
             const KContacts::PhoneNumber::List numbers = mCurrentContact.phoneNumbers();
             if (pos < numbers.count()) {
                 emit mParent->phoneNumberClicked(numbers.at(pos));
             }
         } else if (urlScheme == QLatin1String("sms")) {
-            const int pos = url.queryItemValue(QLatin1String("index")).toInt();
+            const int pos = url.queryItemValue(QStringLiteral("index")).toInt();
 
             const KContacts::PhoneNumber::List numbers = mCurrentContact.phoneNumbers();
             if (pos < numbers.count()) {
                 emit mParent->smsClicked(numbers.at(pos));
             }
         } else if (urlScheme == QLatin1String("address")) {
-            const int pos = url.queryItemValue(QLatin1String("index")).toInt();
+            const int pos = url.queryItemValue(QStringLiteral("index")).toInt();
 
             const KContacts::Address::List addresses = mCurrentContact.addresses();
             if (pos < addresses.count()) {
@@ -219,7 +249,7 @@ public:
         if (!job->error()) {
             CollectionFetchJob *fetchJob = qobject_cast<CollectionFetchJob *>(job);
             if (!fetchJob->collections().isEmpty()) {
-                const Collection collection = fetchJob->collections().first();
+                const Collection collection = fetchJob->collections().at(0);
                 addressBookName = collection.displayName();
             }
         }
@@ -239,8 +269,8 @@ public:
     AbstractContactFormatter *mStandardContactFormatter;
     CollectionFetchJob *mParentCollectionFetchJob;
 #ifdef HAVE_PRISON
-    //prison::AbstractBarcode *mQRCode;
-    //prison::AbstractBarcode *mDataMatrix;
+    prison::AbstractBarcode *mQRCode;
+    prison::AbstractBarcode *mDataMatrix;
 #endif // HAVE_PRISON
 };
 
@@ -325,4 +355,9 @@ void ContactViewer::itemRemoved()
     d->mBrowser->clear();
 }
 
+void ContactViewer::updateView()
+{
+    itemChanged(d->mCurrentItem);
+}
+
 #include "moc_contactviewer.cpp"
