@@ -34,6 +34,7 @@
 #include <QKeyEvent>
 #include <QLabel>
 #include <QPushButton>
+#include <QLocale>
 
 #include <kacceleratormanager.h>
 #include <KComboBox>
@@ -46,7 +47,6 @@
 #include <ktextedit.h>
 
 #include <functional>
-#include <KLocale>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
 
@@ -154,7 +154,9 @@ AddressTypeCombo::AddressTypeCombo(QWidget *parent)
     , mType(KContacts::Address::Home)
     , mLastSelected(0)
 {
-    for (int i = 0; i < KContacts::Address::typeList().count(); ++i) {
+    const int count = KContacts::Address::typeList().count();
+    mTypeList.reserve(count + 1);
+    for (int i = 0; i < count; ++i) {
         mTypeList.append(KContacts::Address::typeList().at(i));
     }
     mTypeList.append(-1);   // Others...
@@ -241,8 +243,8 @@ AddressEditWidget::AddressEditWidget(QWidget *parent)
     hboxLayout->addWidget(label);
 
     mAddressSelectionWidget = new AddressSelectionWidget(this);
-    connect(mAddressSelectionWidget, SIGNAL(selectionChanged(KContacts::Address)),
-            SLOT(updateAddressView()));
+    connect(mAddressSelectionWidget, &AddressSelectionWidget::selectionChanged,
+            this, &AddressEditWidget::updateAddressView);
     label->setBuddy(mAddressSelectionWidget);
     hboxLayout->addWidget(mAddressSelectionWidget, 1);
     layout->addLayout(hboxLayout, 0, 0, 1, 3);
@@ -509,7 +511,7 @@ AddressEditDialog::~AddressEditDialog()
 void AddressEditDialog::editLabel()
 {
     bool ok = false;
-    QString result = QInputDialog::getMultiLineText(this, KContacts::Address::labelLabel(),
+    const QString result = QInputDialog::getMultiLineText(this, KContacts::Address::labelLabel(),
                      KContacts::Address::labelLabel(),
                      mLabel, &ok);
     if (ok) {
@@ -532,7 +534,7 @@ void AddressEditDialog::setAddress(const KContacts::Address &address)
 
     if (mAddress.isEmpty()) {
         mCountryCombo->setItemText(mCountryCombo->currentIndex(),
-                                   KLocale::global()->countryCodeToName(KLocale::global()->country()));
+                                   QLocale::countryToString(QLocale().country()));
     } else {
         mCountryCombo->setItemText(mCountryCombo->currentIndex(), mAddress.country());
     }
@@ -565,10 +567,14 @@ KContacts::Address AddressEditDialog::address() const
 void AddressEditDialog::fillCountryCombo()
 {
     QStringList countries;
-    const QStringList countryList = KLocale::global()->allCountriesList();
-    countries.reserve(countryList.count());
-    foreach (const QString &cc, countryList) {
-        countries.append(KLocale::global()->countryCodeToName(cc));
+    const QList<QLocale> localeList = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
+    countries.reserve(localeList.count());
+    foreach (const QLocale &locale, localeList) {
+        const QString localeStr = QLocale::countryToString(locale.country());
+        if (countries.contains(localeStr)) {
+            continue;
+        }
+        countries.append(localeStr);
     }
 
     qSort(countries.begin(), countries.end(), LocaleAwareLessThan());
@@ -578,7 +584,7 @@ void AddressEditDialog::fillCountryCombo()
     mCountryCombo->completionObject()->setItems(countries);
     mCountryCombo->completionObject()->setIgnoreCase(true);
 
-    const QString currentCountry = KLocale::global()->countryCodeToName(KLocale::global()->country());
+    const QString currentCountry = QLocale::countryToString(QLocale().country());
     mCountryCombo->setCurrentIndex(mCountryCombo->findText(currentCountry));
 }
 
