@@ -39,5 +39,5 @@ void MailDirImport::runTest()
     while (!done) {
         QTest::qWait(WAIT_TIME);
     }
-    outputStats(QLatin1String("import"));
+    outputStats(QStringLiteral("import"));
 }
