@@ -110,7 +110,7 @@ void FakeJobResponse::doCommand()
         setProperty("FetchCollectionId", m_parentCollection.id());
         emit_itemsFetched(Akonadi::valuesToVector(m_items));
     } else if (m_type == RespondToTagFetch) {
-        emit_tagsFetched(m_tags.values());
+        emit_tagsFetched(Akonadi::valuesToVector(m_tags));
     }
 }
 
@@ -201,7 +201,7 @@ void FakeJobResponse::parseEntityString(QList<FakeJobResponse *> &collectionResp
             QString typesString = parts.takeFirst();
 
             QStringList types = typesString.split(QLatin1Char(','));
-            types.replaceInStrings(QLatin1String(" "), QLatin1String(""));
+            types.replaceInStrings(QStringLiteral(" "), QLatin1String(""));
             collection.setContentMimeTypes(types);
         } else {
             parts.removeFirst();
@@ -253,10 +253,10 @@ void FakeJobResponse::parseEntityString(QList<FakeJobResponse *> &collectionResp
     }
     if (entityString.startsWith(QLatin1Char('I'))) {
         Item item;
+        int order = 0;
         entityString.remove(0, 2);
         entityString = entityString.trimmed();
         QString type;
-        int order = 0;
         int iFirstSpace = entityString.indexOf(QLatin1Char(' '));
         type = entityString.left(iFirstSpace);
         entityString = entityString.remove(0, iFirstSpace + 1).trimmed();
@@ -281,6 +281,7 @@ void FakeJobResponse::parseEntityString(QList<FakeJobResponse *> &collectionResp
         } else {
             type = entityString;
         }
+        Q_UNUSED(order);
 
         item.setMimeType(type);
         item.setId(fakeServerData->nextItemId());
