@@ -35,13 +35,13 @@
 #include "session_p.h"
 #include "statusadaptor.h"
 
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
+#include <akonadi/private/standarddirs_p.h>
+
 #include "akonadiagentbase_debug.h"
-#include <kglobal.h>
+
 #include <KLocalizedString>
+#include <KSharedConfig>
 
-#include <k4aboutdata.h>
 #include <Kdelibs4ConfigMigrator>
 
 #include <QtCore/QDir>
@@ -49,6 +49,9 @@
 #include <QtCore/QTimer>
 #include <QtDBus/QtDBus>
 #include <QApplication>
+#include <QtCore/QCommandLineParser>
+#include <QtNetwork/QNetworkConfiguration>
+#include <QNetworkConfigurationManager>
 
 #include <signal.h>
 #include <stdlib.h>
@@ -138,8 +141,8 @@ void AgentBase::ObserverV2::itemLinked(const Akonadi::Item &item, const Akonadi:
     Q_UNUSED(collection);
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemLinked(Akonadi::Item,Akonadi::Collection)),
-                            sAgentBase->d_ptr, SLOT(itemLinked(Akonadi::Item,Akonadi::Collection)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemLinked,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemLinked);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -150,8 +153,8 @@ void AgentBase::ObserverV2::itemUnlinked(const Akonadi::Item &item, const Akonad
     Q_UNUSED(collection);
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemUnlinked(Akonadi::Item,Akonadi::Collection)),
-                            sAgentBase->d_ptr, SLOT(itemUnlinked(Akonadi::Item,Akonadi::Collection)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemUnlinked,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemUnlinked);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -180,8 +183,8 @@ void AgentBase::ObserverV3::itemsFlagsChanged(const Akonadi::Item::List &items,
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)),
-                            sAgentBase->d_ptr, SLOT(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsFlagsChanged,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemsFlagsChanged);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -194,8 +197,8 @@ void AgentBase::ObserverV3::itemsMoved(const Akonadi::Item::List &items, const C
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)),
-                            sAgentBase->d_ptr, SLOT(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsMoved,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemsMoved);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -206,8 +209,8 @@ void AgentBase::ObserverV3::itemsRemoved(const Akonadi::Item::List &items)
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemsRemoved(Akonadi::Item::List)),
-                            sAgentBase->d_ptr, SLOT(itemsRemoved(Akonadi::Item::List)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsRemoved,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemsRemoved);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -219,8 +222,8 @@ void AgentBase::ObserverV3::itemsLinked(const Akonadi::Item::List &items, const
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemsLinked(Akonadi::Item::List,Akonadi::Collection)),
-                            sAgentBase->d_ptr, SLOT(itemsLinked(Akonadi::Item::List,Akonadi::Collection)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsLinked,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemsLinked);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -232,8 +235,8 @@ void AgentBase::ObserverV3::itemsUnlinked(const Akonadi::Item::List &items, cons
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)),
-                            sAgentBase->d_ptr, SLOT(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsUnlinked,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemsUnlinked);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -244,8 +247,8 @@ void AgentBase::ObserverV4::tagAdded(const Tag &tag)
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(tagAdded(Akonadi::Tag)),
-                            sAgentBase->d_ptr, SLOT(tagAdded(Akonadi::Tag)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::tagAdded,
+                            sAgentBase->d_ptr, &AgentBasePrivate::tagAdded);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -256,8 +259,8 @@ void AgentBase::ObserverV4::tagChanged(const Tag &tag)
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(tagChanged(Akonadi::Tag)),
-                            sAgentBase->d_ptr, SLOT(tagChanged(Akonadi::Tag)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::tagChanged,
+                            sAgentBase->d_ptr, &AgentBasePrivate::tagChanged);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -268,8 +271,8 @@ void AgentBase::ObserverV4::tagRemoved(const Tag &tag)
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(tagRemoved(Akonadi::Tag)),
-                            sAgentBase->d_ptr, SLOT(tagRemoved(Akonadi::Tag)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::tagRemoved,
+                            sAgentBase->d_ptr, &AgentBasePrivate::tagRemoved);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -282,8 +285,8 @@ void AgentBase::ObserverV4::itemsTagsChanged(const Item::List &items, const QSet
 
     if (sAgentBase != 0) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)),
-                            sAgentBase->d_ptr, SLOT(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsTagsChanged,
+                            sAgentBase->d_ptr, &AgentBasePrivate::itemsTagsChanged);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -294,8 +297,8 @@ void AgentBase::ObserverV4::relationAdded(const Akonadi::Relation &relation)
 
     if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(relationAdded(Akonadi::Relation)),
-                            sAgentBase->d_ptr, SLOT(relationAdded(Akonadi::Relation)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::relationAdded,
+                            sAgentBase->d_ptr, &AgentBasePrivate::relationAdded);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -306,8 +309,8 @@ void AgentBase::ObserverV4::relationRemoved(const Akonadi::Relation &relation)
 
     if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
-        QObject::disconnect(sAgentBase->changeRecorder(), SIGNAL(relationRemoved(Akonadi::Relation)),
-                            sAgentBase->d_ptr, SLOT(relationRemoved(Akonadi::Relation)));
+        QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::relationRemoved,
+                            sAgentBase->d_ptr, &AgentBasePrivate::relationRemoved);
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -332,7 +335,6 @@ void AgentBase::ObserverV4::itemsRelationsChanged(const Akonadi::Item::List &ite
 
 AgentBasePrivate::AgentBasePrivate(AgentBase *parent)
     : q_ptr(parent)
-    , mDBusConnection(QString())
     , mStatusCode(AgentBase::Idle)
     , mProgress(0)
     , mNeedsNetwork(false)
@@ -344,6 +346,8 @@ AgentBasePrivate::AgentBasePrivate(AgentBase *parent)
     , mObserver(0)
     , mPowerInterface(0)
     , mTemporaryOfflineTimer(0)
+    , mEventLoopLocker(0)
+    , mNetworkManager(Q_NULLPTR)
 {
     Internal::setClientType(Internal::Agent);
 }
@@ -359,7 +363,7 @@ void AgentBasePrivate::init()
     Q_Q(AgentBase);
 
     Kdelibs4ConfigMigrator migrate(mId);
-    migrate.setConfigFiles(QStringList() << QString::fromLatin1("%1rc").arg(mId));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("%1rc").arg(mId));
     migrate.migrate();
 
     /**
@@ -367,11 +371,6 @@ void AgentBasePrivate::init()
      */
     SessionPrivate::createDefaultSession(mId.toLatin1());
 
-    if (QThread::currentThread() != QCoreApplication::instance()->thread()) {
-        mDBusConnection = QDBusConnection::connectToBus(QDBusConnection::SessionBus, q->identifier());
-        Q_ASSERT(mDBusConnection.isConnected());
-    }
-
     mTracer = new org::freedesktop::Akonadi::Tracer(ServerManager::serviceName(ServerManager::Server),
             QStringLiteral("/tracing"),
             KDBusConnectionPool::threadConnection(), q);
@@ -382,7 +381,7 @@ void AgentBasePrivate::init()
         q->error(i18n("Unable to register object at dbus: %1", KDBusConnectionPool::threadConnection().lastError().message()));
     }
 
-    mSettings = new QSettings(QString::fromLatin1("%1/agent_config_%2").arg(Internal::xdgSaveDir("config"), mId), QSettings::IniFormat);
+    mSettings = new QSettings(QStringLiteral("%1/agent_config_%2").arg(StandardDirs::saveDir("config"), mId), QSettings::IniFormat);
 
     mChangeRecorder = new ChangeRecorder(q);
     mChangeRecorder->ignoreSession(Session::defaultSession());
@@ -404,24 +403,24 @@ void AgentBasePrivate::init()
         }
     }
 
-    connect(mChangeRecorder, SIGNAL(itemAdded(Akonadi::Item,Akonadi::Collection)),
-            SLOT(itemAdded(Akonadi::Item,Akonadi::Collection)));
-    connect(mChangeRecorder, SIGNAL(itemChanged(Akonadi::Item,QSet<QByteArray>)),
-            SLOT(itemChanged(Akonadi::Item,QSet<QByteArray>)));
-    connect(mChangeRecorder, SIGNAL(collectionAdded(Akonadi::Collection,Akonadi::Collection)),
-            SLOT(collectionAdded(Akonadi::Collection,Akonadi::Collection)));
+    connect(mChangeRecorder, &Monitor::itemAdded,
+            this, &AgentBasePrivate::itemAdded);
+    connect(mChangeRecorder, &Monitor::itemChanged,
+            this, &AgentBasePrivate::itemChanged);
+    connect(mChangeRecorder, &Monitor::collectionAdded,
+            this, &AgentBasePrivate::collectionAdded);
     connect(mChangeRecorder, SIGNAL(collectionChanged(Akonadi::Collection)),
             SLOT(collectionChanged(Akonadi::Collection)));
     connect(mChangeRecorder, SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)),
             SLOT(collectionChanged(Akonadi::Collection,QSet<QByteArray>)));
-    connect(mChangeRecorder, SIGNAL(collectionMoved(Akonadi::Collection,Akonadi::Collection,Akonadi::Collection)),
-            SLOT(collectionMoved(Akonadi::Collection,Akonadi::Collection,Akonadi::Collection)));
-    connect(mChangeRecorder, SIGNAL(collectionRemoved(Akonadi::Collection)),
-            SLOT(collectionRemoved(Akonadi::Collection)));
-    connect(mChangeRecorder, SIGNAL(collectionSubscribed(Akonadi::Collection,Akonadi::Collection)),
-            SLOT(collectionSubscribed(Akonadi::Collection,Akonadi::Collection)));
-    connect(mChangeRecorder, SIGNAL(collectionUnsubscribed(Akonadi::Collection)),
-            SLOT(collectionUnsubscribed(Akonadi::Collection)));
+    connect(mChangeRecorder, &Monitor::collectionMoved,
+            this, &AgentBasePrivate::collectionMoved);
+    connect(mChangeRecorder, &Monitor::collectionRemoved,
+            this, &AgentBasePrivate::collectionRemoved);
+    connect(mChangeRecorder, &Monitor::collectionSubscribed,
+            this, &AgentBasePrivate::collectionSubscribed);
+    connect(mChangeRecorder, &Monitor::collectionUnsubscribed,
+            this, &AgentBasePrivate::collectionUnsubscribed);
 
     connect(q, SIGNAL(status(int,QString)), q, SLOT(slotStatus(int,QString)));
     connect(q, SIGNAL(percent(int)), q, SLOT(slotPercent(int)));
@@ -442,15 +441,7 @@ void AgentBasePrivate::init()
 
     // Use reference counting to allow agents to finish internal jobs when the
     // agent is stopped.
-    KGlobal::ref();
-    if (QThread::currentThread() == QCoreApplication::instance()->thread()) {
-        KGlobal::setAllowQuit(true);
-    }
-
-    // disable session management
-    if (KApplication::kApplication()) {
-        KApplication::kApplication()->disableSessionManagement();
-    }
+    mEventLoopLocker = new QEventLoopLocker();
 
     mResourceTypeName = AgentManager::self()->instance(mId).type().name();
     setProgramName();
@@ -478,7 +469,8 @@ void AgentBasePrivate::setProgramName()
     if (!mName.isEmpty()) {
         programName = i18nc("Name and type of Akonadi resource", "%1 of type %2", mName, mResourceTypeName) ;
     }
-    const_cast<K4AboutData *>(KGlobal::mainComponent().aboutData())->setProgramName(ki18n(programName.toUtf8().constData()));
+
+    QGuiApplication::setApplicationDisplayName(programName);
 }
 
 void AgentBasePrivate::itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection)
@@ -777,7 +769,7 @@ void AgentBasePrivate::collectionUnsubscribed(const Akonadi::Collection &collect
 void AgentBasePrivate::changeProcessed()
 {
     mChangeRecorder->changeProcessed();
-    QTimer::singleShot(0, mChangeRecorder, SLOT(replayNext()));
+    QTimer::singleShot(0, mChangeRecorder, &ChangeRecorder::replayNext);
 }
 
 void AgentBasePrivate::slotStatus(int status, const QString &message)
@@ -829,17 +821,17 @@ void AgentBasePrivate::slotPercent(int progress)
 
 void AgentBasePrivate::slotWarning(const QString &message)
 {
-    mTracer->warning(QString::fromLatin1("AgentBase(%1)").arg(mId), message);
+    mTracer->warning(QStringLiteral("AgentBase(%1)").arg(mId), message);
 }
 
 void AgentBasePrivate::slotError(const QString &message)
 {
-    mTracer->error(QString::fromLatin1("AgentBase(%1)").arg(mId), message);
+    mTracer->error(QStringLiteral("AgentBase(%1)").arg(mId), message);
 }
 
-void AgentBasePrivate::slotNetworkStatusChange(Solid::Networking::Status stat)
+void AgentBasePrivate::slotNetworkStatusChange(bool isOnline)
 {
-    Q_UNUSED(stat);
+    Q_UNUSED(isOnline);
     Q_Q(AgentBase);
     q->setOnlineInternal(mDesiredOnlineState);
 }
@@ -847,7 +839,7 @@ void AgentBasePrivate::slotNetworkStatusChange(Solid::Networking::Status stat)
 void AgentBasePrivate::slotResumedFromSuspend()
 {
     if (mNeedsNetwork) {
-        slotNetworkStatusChange(Solid::Networking::status());
+        slotNetworkStatusChange(mNetworkManager->isOnline());
     }
 }
 
@@ -919,33 +911,38 @@ AgentBase::~AgentBase()
 
 QString AgentBase::parseArguments(int argc, char **argv)
 {
-    QString identifier;
-    if (argc < 3) {
-        qCDebug(AKONADIAGENTBASE_LOG) << "Not enough arguments passed...";
-        exit(1);
-    }
+    Q_UNUSED(argc);
 
-    for (int i = 1; i < argc - 1; ++i) {
-        if (QLatin1String(argv[i]) == QLatin1String("--identifier")) {
-            identifier = QLatin1String(argv[i + 1]);
-        }
-    }
+    QCommandLineOption identifierOption(QStringLiteral("identifier"), i18n("Agent identifier"),
+                                        QStringLiteral("argument"));
+    QCommandLineParser parser;
+    parser.addOption(identifierOption);
+    parser.addHelpOption();
+    parser.addVersionOption();
+    parser.process(*qApp);
+    parser.setApplicationDescription(i18n("Akonadi Agent"));
 
-    if (identifier.isEmpty()) {
+    if (!parser.isSet(identifierOption)) {
         qCDebug(AKONADIAGENTBASE_LOG) << "Identifier argument missing";
         exit(1);
     }
 
+    const QString identifier = parser.value(identifierOption);
+    if (identifier.isEmpty()) {
+        qCDebug(AKONADIAGENTBASE_LOG) << "Identifier argument is empty";
+        exit(1);
+    }
+
+    QCoreApplication::setApplicationName(ServerManager::addNamespace(identifier));
+    QCoreApplication::setApplicationVersion(QStringLiteral(AKONADILIBRARIES_VERSION_STRING));
+
     const QFileInfo fi(QString::fromLocal8Bit(argv[0]));
     // strip off full path and possible .exe suffix
-    const QByteArray catalog = fi.baseName().toLatin1();
+    const QString catalog = fi.baseName();
 
-    KCmdLineArgs::init(argc, argv, ServerManager::addNamespace(identifier).toLatin1(), catalog, ki18n("Akonadi Agent"), AKONADILIBRARIES_VERSION_STRING,
-                       ki18n("Akonadi Agent"));
-
-    KCmdLineOptions options;
-    options.add("identifier <argument>", ki18n("Agent identifier"));
-    KCmdLineArgs::addCmdLineOptions(options);
+    QTranslator *translator = new QTranslator();
+    translator->load(catalog);
+    QCoreApplication::installTranslator(translator);
 
     return identifier;
 }
@@ -954,9 +951,8 @@ QString AgentBase::parseArguments(int argc, char **argv)
 
 int AgentBase::init(AgentBase *r)
 {
-    QApplication::setQuitOnLastWindowClosed(false);
     KLocalizedString::setApplicationDomain("libakonadi5");
-    int rv = kapp->exec();
+    int rv = qApp->exec();
     delete r;
     return rv;
 }
@@ -999,16 +995,20 @@ bool AgentBase::isOnline() const
 void AgentBase::setNeedsNetwork(bool needsNetwork)
 {
     Q_D(AgentBase);
+    if (d->mNeedsNetwork == needsNetwork) {
+        return;
+    }
+
     d->mNeedsNetwork = needsNetwork;
 
     if (d->mNeedsNetwork) {
-        connect(Solid::Networking::notifier()
-                , SIGNAL(statusChanged(Solid::Networking::Status))
-                , this, SLOT(slotNetworkStatusChange(Solid::Networking::Status))
-                , Qt::UniqueConnection);
+        d->mNetworkManager = new QNetworkConfigurationManager(this);
+        connect(d->mNetworkManager, SIGNAL(onlineStateChanged(bool)),
+                this, SLOT(slotNetworkStatusChange(bool)),
+                Qt::UniqueConnection);
 
     } else {
-        disconnect(Solid::Networking::notifier(), 0, 0, 0);
+        delete d->mNetworkManager;
         setOnlineInternal(d->mDesiredOnlineState);
     }
 }
@@ -1045,8 +1045,7 @@ void AgentBase::setOnlineInternal(bool state)
 {
     Q_D(AgentBase);
     if (state && d->mNeedsNetwork) {
-        const Solid::Networking::Status stat = Solid::Networking::status();
-        if (stat != Solid::Networking::Unknown && stat != Solid::Networking::Connected) {
+        if (!d->mNetworkManager->isOnline()) {
             //Don't go online if the resource needs network but there is none
             state = false;
         }
@@ -1114,7 +1113,8 @@ void AgentBase::quit()
         d->mSettings->sync();
     }
 
-    KGlobal::deref();
+    delete d->mEventLoopLocker;
+    d->mEventLoopLocker = Q_NULLPTR;
 }
 
 void AgentBase::aboutToQuit()
@@ -1155,7 +1155,8 @@ void AgentBase::cleanup()
     QString configFile = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + config()->name();
     QFile::remove(configFile);
 
-    KGlobal::deref();
+    delete d->mEventLoopLocker;
+    d->mEventLoopLocker = Q_NULLPTR;
 }
 
 void AgentBase::registerObserver(Observer *observer)
@@ -1166,65 +1167,65 @@ void AgentBase::registerObserver(Observer *observer)
     const bool hasObserverV3 = (dynamic_cast<AgentBase::ObserverV3 *>(d_ptr->mObserver) != 0);
     const bool hasObserverV4 = (dynamic_cast<AgentBase::ObserverV4 *>(d_ptr->mObserver) != 0);
 
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(tagAdded(Akonadi::Tag)),
-               d_ptr, SLOT(tagAdded(Akonadi::Tag)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(tagChanged(Akonadi::Tag)),
-               d_ptr, SLOT(tagChanged(Akonadi::Tag)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(tagRemoved(Akonadi::Tag)),
-               d_ptr, SLOT(tagRemoved(Akonadi::Tag)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)),
-               d_ptr, SLOT(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)),
-               d_ptr, SLOT(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)),
-               d_ptr, SLOT(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemsRemoved(Akonadi::Item::List)),
-               d_ptr, SLOT(itemsRemoved(Akonadi::Item::List)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemsLinked(Akonadi::Item::List,Akonadi::Collection)),
-               d_ptr, SLOT(itemsLinked(Akonadi::Item::List,Akonadi::Collection)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)),
-               d_ptr, SLOT(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)),
-               d_ptr, SLOT(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemRemoved(Akonadi::Item)),
-               d_ptr, SLOT(itemRemoved(Akonadi::Item)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemLinked(Akonadi::Item,Akonadi::Collection)),
-               d_ptr, SLOT(itemLinked(Akonadi::Item,Akonadi::Collection)));
-    disconnect(d_ptr->mChangeRecorder, SIGNAL(itemUnlinked(Akonadi::Item,Akonadi::Collection)),
-               d_ptr, SLOT(itemUnlinked(Akonadi::Item,Akonadi::Collection)));
+    disconnect(d_ptr->mChangeRecorder, &Monitor::tagAdded,
+               d_ptr, &AgentBasePrivate::tagAdded);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::tagChanged,
+               d_ptr, &AgentBasePrivate::tagChanged);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::tagRemoved,
+               d_ptr, &AgentBasePrivate::tagRemoved);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemsTagsChanged,
+               d_ptr, &AgentBasePrivate::itemsTagsChanged);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemsFlagsChanged,
+               d_ptr, &AgentBasePrivate::itemsFlagsChanged);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemsMoved,
+               d_ptr, &AgentBasePrivate::itemsMoved);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemsRemoved,
+               d_ptr, &AgentBasePrivate::itemsRemoved);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemsLinked,
+               d_ptr, &AgentBasePrivate::itemsLinked);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemsUnlinked,
+               d_ptr, &AgentBasePrivate::itemsUnlinked);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemMoved,
+               d_ptr, &AgentBasePrivate::itemMoved);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemRemoved,
+               d_ptr, &AgentBasePrivate::itemRemoved);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemLinked,
+               d_ptr, &AgentBasePrivate::itemLinked);
+    disconnect(d_ptr->mChangeRecorder, &Monitor::itemUnlinked,
+               d_ptr, &AgentBasePrivate::itemUnlinked);
 
     if (hasObserverV4) {
-        connect(d_ptr->mChangeRecorder, SIGNAL(tagAdded(Akonadi::Tag)),
-                d_ptr, SLOT(tagAdded(Akonadi::Tag)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(tagChanged(Akonadi::Tag)),
-                d_ptr, SLOT(tagChanged(Akonadi::Tag)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(tagRemoved(Akonadi::Tag)),
-                d_ptr, SLOT(tagRemoved(Akonadi::Tag)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)),
-                d_ptr, SLOT(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)));
+        connect(d_ptr->mChangeRecorder, &Monitor::tagAdded,
+                d_ptr, &AgentBasePrivate::tagAdded);
+        connect(d_ptr->mChangeRecorder, &Monitor::tagChanged,
+                d_ptr, &AgentBasePrivate::tagChanged);
+        connect(d_ptr->mChangeRecorder, &Monitor::tagRemoved,
+                d_ptr, &AgentBasePrivate::tagRemoved);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemsTagsChanged,
+                d_ptr, &AgentBasePrivate::itemsTagsChanged);
     }
 
     if (hasObserverV3) {
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)),
-                d_ptr, SLOT(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)),
-                d_ptr, SLOT(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemsRemoved(Akonadi::Item::List)),
-                d_ptr, SLOT(itemsRemoved(Akonadi::Item::List)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemsLinked(Akonadi::Item::List,Akonadi::Collection)),
-                d_ptr, SLOT(itemsLinked(Akonadi::Item::List,Akonadi::Collection)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)),
-                d_ptr, SLOT(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)));
+        connect(d_ptr->mChangeRecorder, &Monitor::itemsFlagsChanged,
+                d_ptr, &AgentBasePrivate::itemsFlagsChanged);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemsMoved,
+                d_ptr, &AgentBasePrivate::itemsMoved);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemsRemoved,
+                d_ptr, &AgentBasePrivate::itemsRemoved);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemsLinked,
+                d_ptr, &AgentBasePrivate::itemsLinked);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemsUnlinked,
+                d_ptr, &AgentBasePrivate::itemsUnlinked);
     } else {
         // V2 - don't connect these if we have V3
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)),
-                d_ptr, SLOT(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemRemoved(Akonadi::Item)),
-                d_ptr, SLOT(itemRemoved(Akonadi::Item)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemLinked(Akonadi::Item,Akonadi::Collection)),
-                d_ptr, SLOT(itemLinked(Akonadi::Item,Akonadi::Collection)));
-        connect(d_ptr->mChangeRecorder, SIGNAL(itemUnlinked(Akonadi::Item,Akonadi::Collection)),
-                d_ptr, SLOT(itemUnlinked(Akonadi::Item,Akonadi::Collection)));
+        connect(d_ptr->mChangeRecorder, &Monitor::itemMoved,
+                d_ptr, &AgentBasePrivate::itemMoved);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemRemoved,
+                d_ptr, &AgentBasePrivate::itemRemoved);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemLinked,
+                d_ptr, &AgentBasePrivate::itemLinked);
+        connect(d_ptr->mChangeRecorder, &Monitor::itemUnlinked,
+                d_ptr, &AgentBasePrivate::itemUnlinked);
     }
 }
 
@@ -1280,11 +1281,7 @@ ChangeRecorder *AgentBase::changeRecorder() const
 
 KSharedConfigPtr AgentBase::config()
 {
-    if (QCoreApplication::instance()->thread() == QThread::currentThread()) {
-        return KSharedConfig::openConfig();
-    } else {
-        return componentData().config();
-    }
+    return KSharedConfig::openConfig();
 }
 
 void AgentBase::abort()
@@ -1297,21 +1294,5 @@ void AgentBase::reconfigure()
     emit reloadConfiguration();
 }
 
-extern QThreadStorage<KComponentData *> s_agentComponentDatas;
-
-KComponentData AgentBase::componentData()
-{
-    if (QThread::currentThread() == QCoreApplication::instance()->thread()) {
-        if (s_agentComponentDatas.hasLocalData()) {
-            return *(s_agentComponentDatas.localData());
-        } else {
-            return KGlobal::mainComponent();
-        }
-    }
-
-    Q_ASSERT(s_agentComponentDatas.hasLocalData());
-    return *(s_agentComponentDatas.localData());
-}
-
 #include "moc_agentbase.cpp"
 #include "moc_agentbase_p.cpp"
