@@ -49,8 +49,6 @@
 #include "recursivemover_p.h"
 #include "tagmodifyjob.h"
 
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
 #include "akonadiagentbase_debug.h"
 #include <KLocalizedString>
 
@@ -109,7 +107,7 @@ public:
         {
             QString reason = KDBusConnectionPool::threadConnection().lastError().message();
             if (reason.isEmpty()) {
-                reason = QString::fromLatin1("this service is probably running already.");
+                reason = QStringLiteral("this service is probably running already.");
             }
             qCritical() << "Unable to register service" << serviceId << "at D-Bus:" << reason;
 
@@ -126,7 +124,7 @@ public:
         if (m_recursiveMover)
         {
             m_recursiveMover->changeProcessed();
-            QTimer::singleShot(0, m_recursiveMover, SLOT(replayNext()));
+            QTimer::singleShot(0, m_recursiveMover.data(), &RecursiveMover::replayNext);
             return;
         }
 
@@ -198,7 +196,7 @@ public:
             mItemSyncer->setProperty("collection", QVariant::fromValue(q->currentCollection()));
             connect(mItemSyncer, SIGNAL(percent(KJob*,ulong)), q, SLOT(slotPercent(KJob*,ulong)));
             connect(mItemSyncer, SIGNAL(result(KJob*)), q, SLOT(slotItemSyncDone(KJob*)));
-            connect(mItemSyncer, SIGNAL(readyForNextBatch(int)), q, SIGNAL(retrieveNextItemSyncBatch(int)));
+            connect(mItemSyncer, &ItemSync::readyForNextBatch, q, &ResourceBase::retrieveNextItemSyncBatch);
         }
         Q_ASSERT(mItemSyncer);
     }
@@ -480,22 +478,24 @@ ResourceBase::ResourceBase(const QString &id)
 {
     Q_D(ResourceBase);
 
+    qDBusRegisterMetaType<QByteArrayList>();
+
     new Akonadi__ResourceAdaptor(this);
 
     d->scheduler = new ResourceScheduler(this);
 
     d->mChangeRecorder->setChangeRecordingEnabled(true);
     d->mChangeRecorder->setCollectionMoveTranslationEnabled(false);   // we deal with this ourselves
-    connect(d->mChangeRecorder, SIGNAL(changesAdded()),
-            d->scheduler, SLOT(scheduleChangeReplay()));
+    connect(d->mChangeRecorder, &ChangeRecorder::changesAdded,
+            d->scheduler, &ResourceScheduler::scheduleChangeReplay);
 
     d->mChangeRecorder->setResourceMonitored(d->mId.toLatin1());
     d->mChangeRecorder->fetchCollection(true);
 
-    connect(d->scheduler, SIGNAL(executeFullSync()),
-            SLOT(retrieveCollections()));
-    connect(d->scheduler, SIGNAL(executeCollectionTreeSync()),
-            SLOT(retrieveCollections()));
+    connect(d->scheduler, &ResourceScheduler::executeFullSync,
+            this, &ResourceBase::retrieveCollections);
+    connect(d->scheduler, &ResourceScheduler::executeCollectionTreeSync,
+            this, &ResourceBase::retrieveCollections);
     connect(d->scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection)),
             SLOT(slotSynchronizeCollection(Akonadi::Collection)));
     connect(d->scheduler, SIGNAL(executeCollectionAttributesSync(Akonadi::Collection)),
@@ -512,20 +512,20 @@ ResourceBase::ResourceBase(const QString &id)
             SLOT(slotInvalidateCache(Akonadi::Collection)));
     connect(d->scheduler, SIGNAL(status(int,QString)),
             SIGNAL(status(int,QString)));
-    connect(d->scheduler, SIGNAL(executeChangeReplay()),
-            d->mChangeRecorder, SLOT(replayNext()));
+    connect(d->scheduler, &ResourceScheduler::executeChangeReplay,
+            d->mChangeRecorder, &ChangeRecorder::replayNext);
     connect(d->scheduler, SIGNAL(executeRecursiveMoveReplay(RecursiveMover*)),
             SLOT(slotRecursiveMoveReplay(RecursiveMover*)));
-    connect(d->scheduler, SIGNAL(fullSyncComplete()), SIGNAL(synchronized()));
-    connect(d->scheduler, SIGNAL(collectionTreeSyncComplete()), SIGNAL(collectionTreeSynchronized()));
-    connect(d->mChangeRecorder, SIGNAL(nothingToReplay()), d->scheduler, SLOT(taskDone()));
-    connect(d->mChangeRecorder, SIGNAL(collectionRemoved(Akonadi::Collection)),
-            d->scheduler, SLOT(collectionRemoved(Akonadi::Collection)));
+    connect(d->scheduler, &ResourceScheduler::fullSyncComplete, this, &ResourceBase::synchronized);
+    connect(d->scheduler, &ResourceScheduler::collectionTreeSyncComplete, this, &ResourceBase::collectionTreeSynchronized);
+    connect(d->mChangeRecorder, &ChangeRecorder::nothingToReplay, d->scheduler, &ResourceScheduler::taskDone);
+    connect(d->mChangeRecorder, &Monitor::collectionRemoved,
+            d->scheduler, &ResourceScheduler::collectionRemoved);
     connect(this, SIGNAL(abortRequested()), this, SLOT(slotAbortRequested()));
-    connect(this, SIGNAL(synchronized()), d->scheduler, SLOT(taskDone()));
-    connect(this, SIGNAL(collectionTreeSynchronized()), d->scheduler, SLOT(taskDone()));
-    connect(this, SIGNAL(agentNameChanged(QString)),
-            this, SIGNAL(nameChanged(QString)));
+    connect(this, &ResourceBase::synchronized, d->scheduler, &ResourceScheduler::taskDone);
+    connect(this, &ResourceBase::collectionTreeSynchronized, d->scheduler, &ResourceScheduler::taskDone);
+    connect(this, &AgentBase::agentNameChanged,
+            this, &ResourceBase::nameChanged);
 
     connect(&d->mProgressEmissionCompressor, SIGNAL(timeout()),
             this, SLOT(slotDelayedEmitProgress()));
@@ -561,45 +561,49 @@ QString ResourceBase::name() const
 
 QString ResourceBase::parseArguments(int argc, char **argv)
 {
-    QString identifier;
-    if (argc < 3) {
-        qCDebug(AKONADIAGENTBASE_LOG) << "Not enough arguments passed...";
-        exit(1);
-    }
+    Q_UNUSED(argc);
 
-    for (int i = 1; i < argc - 1; ++i) {
-        if (QLatin1String(argv[i]) == QLatin1String("--identifier")) {
-            identifier = QLatin1String(argv[i + 1]);
-        }
-    }
+    QCommandLineOption identifierOption(QStringLiteral("identifier"),
+                                        i18nc("@label command line option", "Resource identifier"),
+                                        QStringLiteral("argument"));
+    QCommandLineParser parser;
+    parser.addOption(identifierOption);
+    parser.addHelpOption();
+    parser.addVersionOption();
+    parser.process(*qApp);
+    parser.setApplicationDescription(i18n("Akonadi Resource"));
 
-    if (identifier.isEmpty()) {
+    if (!parser.isSet(identifierOption)) {
         qCDebug(AKONADIAGENTBASE_LOG) << "Identifier argument missing";
         exit(1);
     }
 
+    const QString identifier = parser.value(identifierOption);
+
+    if (identifier.isEmpty()) {
+        qCDebug(AKONADIAGENTBASE_LOG) << "Identifier is empty";
+        exit(1);
+    }
+
+    QCoreApplication::setApplicationName(ServerManager::addNamespace(identifier));
+    QCoreApplication::setApplicationVersion(QStringLiteral(AKONADILIBRARIES_VERSION_STRING));
+
     const QFileInfo fi(QString::fromLocal8Bit(argv[0]));
     // strip off full path and possible .exe suffix
-    const QByteArray catalog = fi.baseName().toLatin1();
+    const QString catalog = fi.baseName();
 
-    KCmdLineArgs::init(argc, argv, ServerManager::addNamespace(identifier).toLatin1(), catalog,
-                       ki18nc("@title application name", "Akonadi Resource"), AKONADILIBRARIES_VERSION_STRING,
-                       ki18nc("@title application description", "Akonadi Resource"));
-
-    KCmdLineOptions options;
-    options.add("identifier <argument>",
-                ki18nc("@label commandline option", "Resource identifier"));
-    KCmdLineArgs::addCmdLineOptions(options);
+    QTranslator *translator = new QTranslator();
+    translator->load(catalog);
+    QCoreApplication::installTranslator(translator);
 
     return identifier;
 }
 
 int ResourceBase::init(ResourceBase *r)
 {
-    QApplication::setQuitOnLastWindowClosed(false);
 #warning port to the new way of doing this
 //   KLocalizedString::insertCatalog( QLatin1String( "libakonadi" ) );
-    int rv = kapp->exec();
+    int rv = qApp->exec();
     delete r;
     return rv;
 }
@@ -715,7 +719,7 @@ void ResourceBasePrivate::slotInvalidateCache(const Akonadi::Collection &collect
 {
     Q_Q(ResourceBase);
     InvalidateCacheJob *job = new InvalidateCacheJob(collection, q);
-    connect(job, SIGNAL(result(KJob*)), scheduler, SLOT(taskDone()));
+    connect(job, &KJob::result, scheduler, &ResourceScheduler::taskDone);
 }
 
 void ResourceBase::changeCommitted(const Item &item)
@@ -772,13 +776,7 @@ void ResourceBase::changeCommitted(const Tag &tag)
     connect(job, SIGNAL(result(KJob*)), SLOT(changeCommittedResult(KJob*)));
 }
 
-bool ResourceBase::requestItemDelivery(qint64 uid, const QString &remoteId,
-                                       const QString &mimeType, const QStringList &parts)
-{
-    return requestItemDeliveryV2(uid, remoteId, mimeType, parts).isEmpty();
-}
-
-QString ResourceBase::requestItemDeliveryV2(qint64 uid, const QString &remoteId, const QString &mimeType, const QStringList &_parts)
+QString ResourceBase::requestItemDelivery(qint64 uid, const QString &remoteId, const QString &mimeType, const QByteArrayList &parts)
 {
     Q_D(ResourceBase);
     if (!isOnline()) {
@@ -793,12 +791,7 @@ QString ResourceBase::requestItemDeliveryV2(qint64 uid, const QString &remoteId,
     item.setMimeType(mimeType);
     item.setRemoteId(remoteId);
 
-    QSet<QByteArray> parts;
-    Q_FOREACH (const QString &str, _parts) {
-        parts.insert(str.toLatin1());
-    }
-
-    d->scheduler->scheduleItemFetch(item, parts, message());
+    d->scheduler->scheduleItemFetch(item, QSet<QByteArray>::fromList(parts), message());
 
     return QString();
 
@@ -951,7 +944,13 @@ void ResourceBasePrivate::slotItemRetrievalCollectionFetchDone(KJob *job)
         return;
     }
     Akonadi::CollectionFetchJob *fetchJob = static_cast<Akonadi::CollectionFetchJob *>(job);
-    q->retrieveItems(fetchJob->collections().at(0));
+    const Collection::List collections = fetchJob->collections();
+    if (collections.isEmpty()) {
+        qCWarning(AKONADIAGENTBASE_LOG) << "The fetch job returned empty collection set. This is unexpected.";
+        q->cancelTask(i18n("Failed to retrieve collection for sync."));
+        return;
+    }
+    q->retrieveItems(collections.at(0));
 }
 
 int ResourceBase::itemSyncBatchSize() const
