@@ -322,7 +322,7 @@ void ResourceScheduler::scheduleNext()
     if (mCurrentTask.type != Invalid || isEmpty() || !mOnline) {
         return;
     }
-    QTimer::singleShot(0, this, SLOT(executeNext()));
+    QTimer::singleShot(0, this, &ResourceScheduler::executeNext);
 }
 
 void ResourceScheduler::executeNext()
@@ -452,10 +452,10 @@ void ResourceScheduler::setOnline(bool state)
 void ResourceScheduler::signalTaskToTracker(const Task &task, const QByteArray &taskType, const QString &debugString)
 {
     // if there's a job tracer running, tell it about the new job
-    if (!s_resourcetracker && KDBusConnectionPool::threadConnection().interface()->isServiceRegistered(QLatin1String("org.kde.akonadiconsole"))) {
-        s_resourcetracker = new QDBusInterface(QLatin1String("org.kde.akonadiconsole"),
-                                               QLatin1String("/resourcesJobtracker"),
-                                               QLatin1String("org.freedesktop.Akonadi.JobTracker"),
+    if (!s_resourcetracker && KDBusConnectionPool::threadConnection().interface()->isServiceRegistered(QStringLiteral("org.kde.akonadiconsole"))) {
+        s_resourcetracker = new QDBusInterface(QStringLiteral("org.kde.akonadiconsole"),
+                                               QStringLiteral("/resourcesJobtracker"),
+                                               QStringLiteral("org.freedesktop.Akonadi.JobTracker"),
                                                KDBusConnectionPool::threadConnection(), 0);
     }
 
@@ -493,8 +493,6 @@ void ResourceScheduler::Task::sendDBusReplies(const QString &errorMsg)
         QDBusMessage reply(msg.createReply());
         const QString methodName = msg.member();
         if (methodName == QLatin1String("requestItemDelivery")) {
-            reply << errorMsg.isEmpty();
-        } else if (methodName == QLatin1String("requestItemDeliveryV2")) {
             reply << errorMsg;
         } else if (methodName.isEmpty()) {
             continue; // unittest calls scheduleItemFetch with empty QDBusMessage
