@@ -26,10 +26,11 @@
 #include <QtCore/QMimeData>
 #include <QtCore/QTimer>
 #include <QAbstractProxyModel>
+#include <QMessageBox>
 
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <QUrl>
+#include <QUrlQuery>
 
 #include "attributefactory.h"
 #include "changerecorder.h"
@@ -81,20 +82,6 @@ EntityTreeModel::~EntityTreeModel()
     delete d_ptr;
 }
 
-bool EntityTreeModel::includeUnsubscribed() const
-{
-    return (listFilter() == CollectionFetchScope::NoFilter);
-}
-
-void EntityTreeModel::setIncludeUnsubscribed(bool show)
-{
-    if (show) {
-        setListFilter(CollectionFetchScope::NoFilter);
-    } else {
-        setListFilter(CollectionFetchScope::Enabled);
-    }
-}
-
 CollectionFetchScope::ListFilter EntityTreeModel::listFilter() const
 {
     Q_D(const EntityTreeModel);
@@ -157,6 +144,15 @@ void EntityTreeModel::clearAndReset()
     d->endResetModel();
 }
 
+QHash<int, QByteArray> EntityTreeModel::roleNames() const
+{
+    QHash<int, QByteArray> names = QAbstractItemModel::roleNames();
+    names.insert(EntityTreeModel::UnreadCountRole, "unreadCount");
+    names.insert(EntityTreeModel::FetchStateRole, "fetchState");
+    names.insert(EntityTreeModel::ItemIdRole, "itemId");
+    return names;
+}
+
 int EntityTreeModel::columnCount(const QModelIndex &parent) const
 {
 // TODO: Statistics?
@@ -313,9 +309,6 @@ QVariant EntityTreeModel::data(const QModelIndex &index, int role) const
         case FetchStateRole: {
             return d->m_pendingCollectionRetrieveJobs.contains(collection.id()) ? FetchingState : IdleState;
         }
-        case CollectionSyncProgressRole: {
-            return QVariant(); // no longer supported
-        }
         case IsPopulatedRole: {
             return d->m_populatedCols.contains(collection.id());
         }
@@ -552,12 +545,14 @@ bool EntityTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
                         return false;
                     }
 
-                    if (url.hasQueryItem(QStringLiteral("name"))) {
-                        const QString collectionName = url.queryItemValue(QStringLiteral("name"));
+                    QUrlQuery query(url);
+                    if (query.hasQueryItem(QStringLiteral("name"))) {
+                        const QString collectionName = query.queryItemValue(QStringLiteral("name"));
                         const QStringList collectionNames = d->childCollectionNames(destCollection);
 
                         if (collectionNames.contains(collectionName)) {
-                            KMessageBox::error(0, i18n("The target collection '%1' contains already\na collection with name '%2'.",
+                            QMessageBox::critical(0, i18n("Error"),
+                                                  i18n("The target collection '%1' contains already\na collection with name '%2'.",
                                                        destCollection.name(), collection.name()));
                             return false;
                         }
@@ -774,8 +769,9 @@ QMimeData *EntityTreeModel::mimeData(const QModelIndexList &indexes) const
             urls << d->m_collections.value(node->id).url(Collection::UrlWithName);
         } else if (Node::Item == node->type) {
             QUrl url = d->m_items.value(node->id).url(Item::Item::UrlWithMimeType);
-            // Encode the "virtual" parent
-            url.addQueryItem(QStringLiteral("parent"), QString::number(node->parent));
+            QUrlQuery query;
+            query.addQueryItem(QStringLiteral("parent"), QString::number(node->parent));
+            url.setQuery(query);
             urls << url;
         } else { // if that happens something went horrible wrong
             Q_ASSERT(false);
@@ -851,7 +847,7 @@ bool EntityTreeModel::setData(const QModelIndex &index, const QVariant &value, i
                     return false;
                 }
 
-                EntityDisplayAttribute *eda = collection.attribute<EntityDisplayAttribute>(Entity::AddIfMissing);
+                EntityDisplayAttribute *eda = collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
                 eda->setBackgroundColor(color);
             }
 
@@ -874,7 +870,7 @@ bool EntityTreeModel::setData(const QModelIndex &index, const QVariant &value, i
 
             if (Qt::EditRole == role) {
                 if (item.hasAttribute<EntityDisplayAttribute>()) {
-                    EntityDisplayAttribute *displayAttribute = item.attribute<EntityDisplayAttribute>(Entity::AddIfMissing);
+                    EntityDisplayAttribute *displayAttribute = item.attribute<EntityDisplayAttribute>(Item::AddIfMissing);
                     displayAttribute->setDisplayName(value.toString());
                 }
             }
@@ -886,7 +882,7 @@ bool EntityTreeModel::setData(const QModelIndex &index, const QVariant &value, i
                     return false;
                 }
 
-                EntityDisplayAttribute *eda = item.attribute<EntityDisplayAttribute>(Entity::AddIfMissing);
+                EntityDisplayAttribute *eda = item.attribute<EntityDisplayAttribute>(Item::AddIfMissing);
                 eda->setBackgroundColor(color);
             }
 
@@ -974,22 +970,6 @@ bool EntityTreeModel::isFullyPopulated() const
     return d->m_collectionTreeFetched && d->m_pendingCollectionRetrieveJobs.isEmpty();
 }
 
-bool EntityTreeModel::entityMatch(const Item &item, const QVariant &value, Qt::MatchFlags flags) const
-{
-    Q_UNUSED(item);
-    Q_UNUSED(value);
-    Q_UNUSED(flags);
-    return false;
-}
-
-bool EntityTreeModel::entityMatch(const Collection &collection, const QVariant &value, Qt::MatchFlags flags) const
-{
-    Q_UNUSED(collection);
-    Q_UNUSED(value);
-    Q_UNUSED(flags);
-    return false;
-}
-
 QModelIndexList EntityTreeModel::match(const QModelIndex &start, int role, const QVariant &value, int hits, Qt::MatchFlags flags) const
 {
     Q_D(const EntityTreeModel);
@@ -1053,49 +1033,7 @@ QModelIndexList EntityTreeModel::match(const QModelIndex &start, int role, const
         return list;
     }
 
-    if (role != AmazingCompletionRole) {
-        return QAbstractItemModel::match(start, role, value, hits, flags);
-    }
-
-    // Try to match names, and email addresses.
-    QModelIndexList list;
-
-    if (role < 0 ||
-            !start.isValid() ||
-            !value.isValid()) {
-        return list;
-    }
-
-    const int column = 0;
-    int row = start.row();
-    const QModelIndex parentIndex = start.parent();
-    const int parentRowCount = rowCount(parentIndex);
-
-    while (row < parentRowCount &&
-            (hits == -1 || list.size() < hits)) {
-        const QModelIndex idx = index(row, column, parentIndex);
-        const Item item = idx.data(ItemRole).value<Item>();
-
-        if (!item.isValid()) {
-            const Collection collection = idx.data(CollectionRole).value<Collection>();
-            if (!collection.isValid()) {
-                continue;
-            }
-
-            if (entityMatch(collection, value, flags)) {
-                list << idx;
-            }
-
-        } else {
-            if (entityMatch(item, value, flags)) {
-                list << idx;
-            }
-        }
-
-        ++row;
-    }
-
-    return list;
+    return QAbstractItemModel::match(start, role, value, hits, flags);
 }
 
 bool EntityTreeModel::insertRows(int, int, const QModelIndex &)
