@@ -336,7 +336,6 @@ public:
 
         RemoteIdRole,                           ///< The remoteId of the entity
         CollectionChildOrderRole,               ///< Ordered list of child items if available
-        AmazingCompletionRole,                  ///< Role used to implement amazing completion
         ParentCollectionRole,                   ///< The parent collection of the entity
         ColumnCountRole,                        ///< @internal Used by proxies to determine the number of columns for a header group.
         LoadedPartsRole,                        ///< Parts available in the model for the item
@@ -348,7 +347,6 @@ public:
         EntityUrlRole,                          ///< The akonadi:/ Url of the entity as a string. Item urls will contain the mimetype.
         UnreadCountRole,                        ///< Returns the number of unread items in a collection. @since 4.5
         FetchStateRole,                         ///< Returns the FetchState of a particular item. @since 4.5
-        CollectionSyncProgressRole,             ///< Returns the progress of synchronization in percent for a particular collection. @since 4.6. Deprecated since 4.14.3.
         IsPopulatedRole,                        ///< Returns whether a Collection has been populated, i.e. whether its items have been fetched. @since 4.10
         OriginalCollectionNameRole,             ///< Returns original name for collection @since 4.14
         UserRole = Qt::UserRole + 500,          ///< First role for user extensions.
@@ -424,27 +422,6 @@ public:
      */
     bool systemEntitiesShown() const;
 
-    /**
-     * Returns whether unsubscribed entities will be included in the listing.
-     *
-     * @since 4.5
-     * @deprecated use listFilter instead
-     */
-    AKONADICORE_DEPRECATED bool includeUnsubscribed() const;
-
-    /**
-     * Sets whether unsubscribed entities will be included in the listing.
-     * By default it's true
-     * @param show enables displaying of unsubscribed entities if set as @c true
-     * Note that it is possible to change the monitor's fetchscope directly,
-     *  bypassing this method, which will lead to inconsistencies. Use
-     *  this method for turning on/off listing of subscribed folders.
-     *
-     * @since 4.5
-     * @deprecated use setListFilter instead
-     */
-    AKONADICORE_DEPRECATED void setIncludeUnsubscribed(bool show);
-
     /**
      * Returns the currently used listfilter.
      *
@@ -540,6 +517,8 @@ public:
      */
     CollectionFetchStrategy collectionFetchStrategy() const;
 
+    QHash<int, QByteArray> roleNames() const Q_DECL_OVERRIDE;
+
     int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
     int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
@@ -689,16 +668,6 @@ protected:
 
     virtual int entityColumnCount(HeaderGroup headerGroup) const;
 
-    /**
-     * Reimplement this in a subclass to return true if @p item matches @p value with @p flags in the AmazingCompletionRole.
-     */
-    virtual bool entityMatch(const Item &item, const QVariant &value, Qt::MatchFlags flags) const;
-
-    /**
-     * Reimplement this in a subclass to return true if @p collection matches @p value with @p flags in the AmazingCompletionRole.
-     */
-    virtual bool entityMatch(const Collection &collection, const QVariant &value, Qt::MatchFlags flags) const;
-
 protected:
     //@cond PRIVATE
     Q_DECLARE_PRIVATE(EntityTreeModel)
