@@ -30,7 +30,7 @@
 #include <qdebug.h>
 #include <kiconloader.h>
 #include <KLocalizedString>
-#include <kio/global.h>
+#include <KFormat>
 
 #include <QApplication>
 #include <QPalette>
@@ -41,7 +41,7 @@ using namespace Akonadi;
 /**
  * @internal
  */
-class StatisticsProxyModel::Private
+class Q_DECL_HIDDEN StatisticsProxyModel::Private
 {
 public:
     Private(StatisticsProxyModel *parent)
@@ -79,11 +79,11 @@ public:
         QString bckColor = QApplication::palette().color(QPalette::ToolTipBase).name();
         QString txtColor = QApplication::palette().color(QPalette::ToolTipText).name();
 
-        QString tip = QString::fromLatin1(
+        QString tip = QStringLiteral(
                           "<table width=\"100%\" border=\"0\" cellpadding=\"2\" cellspacing=\"0\">\n"
                       );
         const QString textDirection = (QApplication::layoutDirection() == Qt::LeftToRight) ? QStringLiteral("left") : QStringLiteral("right");
-        tip += QString::fromLatin1(
+        tip += QStringLiteral(
                    "  <tr>\n"
                    "    <td bgcolor=\"%1\" colspan=\"2\" align=\"%4\" valign=\"middle\">\n"
                    "      <div style=\"color: %2; font-weight: bold;\">\n"
@@ -93,13 +93,13 @@ public:
                    "  </tr>\n"
                ).arg(txtColor).arg(bckColor).arg(index.data(Qt::DisplayRole).toString()).arg(textDirection);
 
-        tip += QString::fromLatin1(
+        tip += QStringLiteral(
                    "  <tr>\n"
                    "    <td align=\"%1\" valign=\"top\">\n"
                ).arg(textDirection);
 
         QString tipInfo;
-        tipInfo += QString::fromLatin1(
+        tipInfo += QStringLiteral(
                        "      <strong>%1</strong>: %2<br>\n"
                        "      <strong>%3</strong>: %4<br><br>\n"
                    ).arg(i18n("Total Messages")).arg(collection.statistics().count())
@@ -112,25 +112,26 @@ public:
 
                 if (qAbs(percentage) >= 0.01) {
                     QString percentStr = QString::number(percentage, 'f', 2);
-                    tipInfo += QString::fromLatin1(
+                    tipInfo += QStringLiteral(
                                    "      <strong>%1</strong>: %2%<br>\n"
                                ).arg(i18n("Quota")).arg(percentStr);
                 }
             }
         }
 
+	KFormat formatter;
         qint64 currentFolderSize(collection.statistics().size());
-        tipInfo += QString::fromLatin1(
+        tipInfo += QStringLiteral(
                        "      <strong>%1</strong>: %2<br>\n"
-                   ).arg(i18n("Storage Size")).arg(KIO::convertSize((KIO::filesize_t)(currentFolderSize)));
+                   ).arg(i18n("Storage Size")).arg(formatter.formatByteSize(currentFolderSize));
 
         qint64 totalSize = 0;
         getCountRecursive(index, totalSize);
         totalSize -= currentFolderSize;
         if (totalSize > 0) {
-            tipInfo += QString::fromLatin1(
+            tipInfo += QStringLiteral(
                            "<strong>%1</strong>: %2<br>"
-                       ).arg(i18n("Subfolder Storage Size")).arg(KIO::convertSize((KIO::filesize_t)(totalSize)));
+                       ).arg(i18n("Subfolder Storage Size")).arg(formatter.formatByteSize(totalSize));
         }
 
         QString iconName = CollectionUtils::defaultIconName(collection);
@@ -160,7 +161,7 @@ public:
             iconPath = KIconLoader::global()->iconPath(QStringLiteral("folder"), -32, false);
         }
 
-        QString tipIcon = QString::fromLatin1(
+        QString tipIcon = QStringLiteral(
                               "      <table border=\"0\"><tr><td width=\"32\" height=\"32\" align=\"center\" valign=\"middle\">\n"
                               "      <img src=\"%1\" width=\"%2\" height=\"32\">\n"
                               "      </td></tr></table>\n"
@@ -168,12 +169,12 @@ public:
                           ).arg(iconPath).arg(icon_size_found) ;
 
         if (QApplication::layoutDirection() == Qt::LeftToRight) {
-            tip += tipInfo + QString::fromLatin1("</td><td align=\"%3\" valign=\"top\">").arg(textDirection) + tipIcon;
+            tip += tipInfo + QStringLiteral("</td><td align=\"%3\" valign=\"top\">").arg(textDirection) + tipIcon;
         } else {
-            tip += tipIcon + QString::fromLatin1("</td><td align=\"%3\" valign=\"top\">").arg(textDirection) + tipInfo;
+            tip += tipIcon + QStringLiteral("</td><td align=\"%3\" valign=\"top\">").arg(textDirection) + tipInfo;
         }
 
-        tip += QString::fromLatin1(
+        tip += QLatin1String(
                    "  </tr>" \
                    "</table>"
                );
@@ -385,7 +386,8 @@ QVariant StatisticsProxyModel::data(const QModelIndex &index, int role) const
 
         if (collection.isValid() && collection.statistics().count() >= 0) {
             if (index.column() == sourceColumnCount + 2) {
-                return KIO::convertSize((KIO::filesize_t)(collection.statistics().size()));
+                KFormat formatter;
+                return formatter.formatByteSize(collection.statistics().size());
             } else if (index.column() == sourceColumnCount + 1) {
                 return collection.statistics().count();
             } else if (index.column() == sourceColumnCount) {
