@@ -28,6 +28,7 @@
 #include "notificationmanagerinterface.h"
 #include "session.h"
 #include "changemediator_p.h"
+#include "vectorhelper.h"
 
 #include <qdebug.h>
 
@@ -122,7 +123,7 @@ void MonitorPrivate::serverStateChanged(ServerManager::State state)
             Q_FOREACH (const Collection &col, collections) {
                 notificationSource->setMonitoredCollection(col.id(), true);
             }
-            Q_FOREACH (const Entity::Id id, items) {
+            Q_FOREACH (const Item::Id id, items) {
                 notificationSource->setMonitoredItem(id, true);
             }
             Q_FOREACH (const QByteArray &resource, resources) {
@@ -152,7 +153,7 @@ void MonitorPrivate::invalidateCollectionCache(qint64 id)
 
 void MonitorPrivate::invalidateItemCache(qint64 id)
 {
-    itemCache->update(QList<Entity::Id>() << id, mItemFetchScope);
+    itemCache->update(QList<Item::Id>() << id, mItemFetchScope);
 }
 
 void MonitorPrivate::invalidateTagCache(qint64 id)
@@ -847,7 +848,7 @@ bool MonitorPrivate::emitItemsNotification(const Protocol::ChangeNotification &m
         colDest = Collection(msg.parentDestCollection());
         // HACK: destination resource is delivered in the parts field...
         if (!msg.itemParts().isEmpty()) {
-            colDest.setResource(QString::fromLatin1(*(msg.itemParts().begin())));
+            colDest.setResource(QString::fromLatin1(*(msg.itemParts().cbegin())));
         }
     }
 
@@ -913,6 +914,7 @@ bool MonitorPrivate::emitItemsNotification(const Protocol::ChangeNotification &m
         }
     }
 
+    its.reserve(its.size() + msgEntities.size());
     // Now reconstruct any items there were left in msgItems
     Q_FOREACH (const Protocol::ChangeNotification::Entity &msgItem, msgEntities) {
         Item it(msgItem.id);
@@ -995,7 +997,7 @@ bool MonitorPrivate::emitItemsNotification(const Protocol::ChangeNotification &m
         return handled;
     case Protocol::ChangeNotification::ModifyTags:
         if (q_ptr->receivers(SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>))) > 0) {
-            emit q_ptr->itemsTagsChanged(its, addedTags.toSet(), removedTags.toSet());
+            emit q_ptr->itemsTagsChanged(its, Akonadi::vectorToSet(addedTags), Akonadi::vectorToSet(removedTags));
             return true;
         }
         return false;
@@ -1262,7 +1264,7 @@ int MonitorPrivate::PurgeBuffer::buffersize()
     return MAXBUFFERSIZE;
 }
 
-bool MonitorPrivate::isMonitored(Entity::Id colId) const
+bool MonitorPrivate::isMonitored(Collection::Id colId) const
 {
     if (!useRefCounting) {
         return true;
@@ -1270,7 +1272,7 @@ bool MonitorPrivate::isMonitored(Entity::Id colId) const
     return refCountMap.contains(colId) || m_buffer.isBuffered(colId);
 }
 
-void MonitorPrivate::notifyCollectionStatisticsWatchers(Entity::Id collection, const QByteArray &resource)
+void MonitorPrivate::notifyCollectionStatisticsWatchers(Collection::Id collection, const QByteArray &resource)
 {
     if (collection > 0 && (monitorAll || isCollectionMonitored(collection) || resources.contains(resource))) {
         recentlyChangedCollections.insert(collection);
