@@ -24,14 +24,14 @@
 #include "servermanager.h"
 #include "servermanager_p.h"
 
-#include <akonadi/private/xdgbasedirs_p.h>
+#include <akonadi/private/standarddirs_p.h>
+#include <akonadi/private/protocol_p.h>
 
 #include <QUrl>
 #include <QIcon>
 #include <QFileDialog>
 #include <KLocalizedString>
-#include <KMessageBox>
-#include <KRun>
+#include <QMessageBox>
 #include <QStandardPaths>
 #include <QSqlDatabase>
 #include <QSqlError>
@@ -45,6 +45,7 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QStandardItemModel>
+#include <QDesktopServices>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
@@ -55,7 +56,7 @@ using namespace Akonadi;
 
 static QString makeLink(const QString &file)
 {
-    return QString::fromLatin1("<a href=\"%1\">%2</a>").arg(file, file);
+    return QStringLiteral("<a href=\"%1\">%2</a>").arg(file, file);
 }
 
 enum SelfTestRole {
@@ -83,15 +84,15 @@ SelfTestDialog::SelfTestDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SelfTestDialog::reject);
     mainLayout->addWidget(buttonBox);
     user1Button->setText(i18n("Save Report..."));
-    user1Button->setIcon(QIcon::fromTheme(QString::fromLatin1("document-save")));
+    user1Button->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
     user2Button->setText(i18n("Copy Report to Clipboard"));
-    user2Button->setIcon(QIcon::fromTheme(QString::fromLatin1("edit-copy")));
+    user2Button->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
     ui.setupUi(mainWidget);
 
     mTestModel = new QStandardItemModel(this);
     ui.testView->setModel(mTestModel);
-    connect(ui.testView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            SLOT(selectionChanged(QModelIndex)));
+    connect(ui.testView->selectionModel(), &QItemSelectionModel::currentChanged,
+            this, &SelfTestDialog::selectionChanged);
     connect(ui.detailsLabel, &QLabel::linkActivated, this, &SelfTestDialog::linkActivated);
 
     connect(user1Button, &QPushButton::clicked, this, &SelfTestDialog::saveReport);
@@ -111,17 +112,17 @@ QStandardItem *SelfTestDialog::report(ResultType type, const KLocalizedString &s
     QStandardItem *item = new QStandardItem(summary.toString());
     switch (type) {
     case Skip:
-        item->setIcon(QIcon::fromTheme(QString::fromLatin1("dialog-ok")));
+        item->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok")));
         break;
     case Success:
-        item->setIcon(QIcon::fromTheme(QString::fromLatin1("dialog-ok-apply")));
+        item->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")));
         break;
     case Warning:
-        item->setIcon(QIcon::fromTheme(QString::fromLatin1("dialog-warning")));
+        item->setIcon(QIcon::fromTheme(QStringLiteral("dialog-warning")));
         break;
     case Error:
     default:
-        item->setIcon(QIcon::fromTheme(QString::fromLatin1("dialog-error")));
+        item->setIcon(QIcon::fromTheme(QStringLiteral("dialog-error")));
     }
     item->setEditable(false);
     item->setWhatsThis(details.toString());
@@ -169,7 +170,7 @@ void SelfTestDialog::runTests()
 
 QVariant SelfTestDialog::serverSetting(const QString &group, const char *key, const QVariant &def) const
 {
-    const QString serverConfigFile = XdgBaseDirs::akonadiServerConfigFile(XdgBaseDirs::ReadWrite);
+    const QString serverConfigFile = StandardDirs::serverConfigFile(XdgBaseDirs::ReadOnly);
     QSettings settings(serverConfigFile, QSettings::IniFormat);
     settings.beginGroup(group);
     return settings.value(QString::fromLatin1(key), def);
@@ -216,7 +217,7 @@ void SelfTestDialog::testSQLDriver()
     } else {
         item = report(Error, ki18n("Database driver not found."), detailsFail);
     }
-    item->setData(XdgBaseDirs::akonadiServerConfigFile(XdgBaseDirs::ReadWrite), FileIncludeRole);
+    item->setData(StandardDirs::serverConfigFile(XdgBaseDirs::ReadOnly), FileIncludeRole);
 }
 
 void SelfTestDialog::testMySQLServer()
@@ -268,8 +269,8 @@ void SelfTestDialog::testMySQLServerLog()
         return;
     }
 
-    const QString logFileName = XdgBaseDirs::saveDir("data", QStringLiteral("akonadi/db_data"))
-                                + QDir::separator() + QString::fromLatin1("mysql.err");
+    const QString logFileName = StandardDirs::saveDir("data", QStringLiteral("db_data"))
+                                    + QDir::separator() + QLatin1String("mysql.err");
     const QFileInfo logFileInfo(logFileName);
     if (!logFileInfo.exists() || logFileInfo.size() == 0) {
         report(Success, ki18n("No current MySQL error log found."),
@@ -347,7 +348,7 @@ void SelfTestDialog::testMySQLServerConfig()
                      "Check your access rights.").subs(makeLink(localConfig)));
     }
 
-    const QString actualConfig = XdgBaseDirs::saveDir("data", QStringLiteral("akonadi")) + QStringLiteral("/mysql.conf");
+    const QString actualConfig = StandardDirs::saveDir("data") + QStringLiteral("/mysql.conf");
     const QFileInfo actualConfigInfo(actualConfig);
     if (actualConfig.isEmpty() || !actualConfigInfo.exists() || !actualConfigInfo.isReadable()) {
         report(Error, ki18n("MySQL server configuration not found or not readable."),
@@ -441,18 +442,18 @@ void SelfTestDialog::testProtocolVersion()
                ki18n("Without a connection to the server it is not possible to check if the protocol version meets the requirements."));
         return;
     }
-    if (Internal::serverProtocolVersion() < SessionPrivate::clientProtocolVersion()) {
+    if (Internal::serverProtocolVersion() < Protocol::version()) {
         report(Error, ki18n("Server protocol version is too old."),
                ki18n("The server protocol version is %1, but version %2 is required by the client. "
                      "If you recently updated KDE PIM, please make sure to restart both Akonadi and KDE PIM applications.")
                .subs(Internal::serverProtocolVersion())
-               .subs(SessionPrivate::clientProtocolVersion()));
-    } else if (Internal::serverProtocolVersion() > SessionPrivate::clientProtocolVersion()) {
+               .subs(Protocol::version()));
+    } else if (Internal::serverProtocolVersion() > Protocol::version()) {
         report(Error, ki18n("Server protocol version is too new."),
                ki18n("The server protocol version is %1, but version %2 is required by the client. "
                      "If you recently updated KDE PIM, please make sure to restart both Akonadi and KDE PIM applications.")
                .subs(Internal::serverProtocolVersion())
-               .subs(SessionPrivate::clientProtocolVersion()));
+               .subs(Protocol::version()));
     } else {
         report(Success, ki18n("Server protocol version matches."),
                ki18n("The current Protocol version is %1.")
@@ -491,8 +492,7 @@ void SelfTestDialog::testResources()
 
 void SelfTestDialog::testServerLog()
 {
-    QString serverLog = XdgBaseDirs::saveDir("data", QStringLiteral("akonadi"))
-                        + QDir::separator() + QString::fromLatin1("akonadiserver.error");
+    QString serverLog = StandardDirs::saveDir("data") + QDir::separator() + QLatin1String("akonadiserver.error");
     QFileInfo info(serverLog);
     if (!info.exists() || info.size() <= 0) {
         report(Success, ki18n("No current Akonadi server error log found."),
@@ -517,8 +517,7 @@ void SelfTestDialog::testServerLog()
 
 void SelfTestDialog::testControlLog()
 {
-    QString controlLog = XdgBaseDirs::saveDir("data", QStringLiteral("akonadi"))
-                         + QDir::separator() + QString::fromLatin1("akonadi_control.error");
+    QString controlLog = StandardDirs::saveDir("data") + QDir::separator() + QLatin1String("akonadi_control.error");
     QFileInfo info(controlLog);
     if (!info.exists() || info.size() <= 0) {
         report(Success, ki18n("No current Akonadi control error log found."),
@@ -632,7 +631,7 @@ void SelfTestDialog::saveReport()
 
     QFile file(fileName);
     if (!file.open(QFile::ReadWrite)) {
-        KMessageBox::error(this, i18n("Could not open file '%1'", fileName));
+        QMessageBox::critical(this, i18n("Error"), i18n("Could not open file '%1'", fileName));
         return;
     }
 
@@ -649,7 +648,7 @@ void SelfTestDialog::copyReport()
 
 void SelfTestDialog::linkActivated(const QString &link)
 {
-    KRun::runUrl(QUrl::fromLocalFile(link), QStringLiteral("text/plain"), this);
+    QDesktopServices::openUrl(QUrl::fromLocalFile(link));
 }
 
 // @endcond
