@@ -49,6 +49,7 @@
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KLocalizedString>
+#include <KConfigGroup>
 #include <QMenu>
 #include <KMessageBox>
 #include <KToggleAction>
@@ -60,7 +61,6 @@
 #include <QPointer>
 #include <QWeakPointer>
 #include <QInputDialog>
-#include <boost/static_assert.hpp>
 
 using namespace Akonadi;
 
@@ -125,7 +125,8 @@ static const struct {
 };
 static const int numStandardActionData = sizeof standardActionData / sizeof * standardActionData;
 
-BOOST_STATIC_ASSERT(numStandardActionData == StandardActionManager::LastType);
+static_assert(numStandardActionData == StandardActionManager::LastType,
+              "StandardActionData table does not match StandardActionManager types");
 
 static bool canCreateCollection(const Akonadi::Collection &collection)
 {
@@ -187,7 +188,7 @@ static QModelIndexList safeSelectedRows(QItemSelectionModel *selectionModel)
 /**
  * @internal
  */
-class StandardActionManager::Private
+class Q_DECL_HIDDEN StandardActionManager::Private
 {
 public:
     Private(StandardActionManager *parent)
@@ -343,7 +344,7 @@ public:
         const Akonadi::Collection::List selectedCollectionsList = selectedCollections();
         const StandardActionManager::Type type = static_cast<StandardActionManager::Type>(menu->property("actionType").toInt());
 
-        QWeakPointer<RecentCollectionAction> recentCollection = new RecentCollectionAction(type, selectedCollectionsList, collectionSelectionModel->model(), menu);
+        QPointer<RecentCollectionAction> recentCollection = new RecentCollectionAction(type, selectedCollectionsList, collectionSelectionModel->model(), menu);
         mRecentCollectionsMenu.insert(type, recentCollection);
         const QSet<QString> mimeTypes = mimeTypesOfSelection(type);
         fillFoldersMenu(selectedCollectionsList,
@@ -553,6 +554,7 @@ public:
             _p->insideSelectionSlot = false;
         }
     private:
+        Q_DISABLE_COPY(InsideSelectionSlotBlocker)
         Private *_p;
     };
 
@@ -1263,7 +1265,7 @@ public:
 
     void addRecentCollection(Akonadi::Collection::Id id)
     {
-        QMapIterator<StandardActionManager::Type, QWeakPointer<RecentCollectionAction> > item(mRecentCollectionsMenu);
+        QMapIterator<StandardActionManager::Type, QPointer<RecentCollectionAction> > item(mRecentCollectionsMenu);
         while (item.hasNext()) {
             item.next();
             if (item.value().data()) {
@@ -1420,7 +1422,7 @@ public:
                 // new level
                 QMenu *popup = new QMenu(menu);
                 const bool moveAction = (type == MoveCollectionToMenu || type == MoveItemToMenu);
-                popup->setObjectName(QString::fromUtf8("subMenu"));
+                popup->setObjectName(QStringLiteral("subMenu"));
                 popup->setTitle(label);
                 popup->setIcon(icon);
 
@@ -1570,7 +1572,7 @@ public:
     QStringList mMimeTypeFilter;
     QStringList mCapabilityFilter;
     QStringList mCollectionPropertiesPageNames;
-    QMap<StandardActionManager::Type, QWeakPointer<RecentCollectionAction> > mRecentCollectionsMenu;
+    QMap<StandardActionManager::Type, QPointer<RecentCollectionAction> > mRecentCollectionsMenu;
 };
 
 //@endcond
