@@ -184,8 +184,8 @@ void LDAPProtocol::controlsFromMetaData(LdapControls &serverctrls,
     bool critical;
     QByteArray value;
     int i = 0;
-    while (hasMetaData(QString::fromLatin1("SERVER_CTRL%1").arg(i))) {
-        QByteArray val = metaData(QString::fromLatin1("SERVER_CTRL%1").arg(i)).toUtf8();
+    while (hasMetaData(QStringLiteral("SERVER_CTRL%1").arg(i))) {
+        QByteArray val = metaData(QStringLiteral("SERVER_CTRL%1").arg(i)).toUtf8();
         Ldif::splitControl(val, oid, critical, value);
         qCDebug(KLDAP_LOG) << "server ctrl #" << i << " value: " << val <<
                            " oid: " << oid << " critical: " << critical << " value: " <<
@@ -195,8 +195,8 @@ void LDAPProtocol::controlsFromMetaData(LdapControls &serverctrls,
         i++;
     }
     i = 0;
-    while (hasMetaData(QString::fromLatin1("CLIENT_CTRL%1").arg(i))) {
-        QByteArray val = metaData(QString::fromLatin1("CLIENT_CTRL%1").arg(i)).toUtf8();
+    while (hasMetaData(QStringLiteral("CLIENT_CTRL%1").arg(i))) {
+        QByteArray val = metaData(QStringLiteral("CLIENT_CTRL%1").arg(i)).toUtf8();
         Ldif::splitControl(val, oid, critical, value);
         qCDebug(KLDAP_LOG) << "client ctrl #" << i << " value: " << val <<
                            " oid: " << oid << " critical: " << critical << " value: " <<
@@ -231,7 +231,7 @@ void LDAPProtocol::LDAPEntry2UDSEntry(const LdapDN &dn, UDSEntry &entry,
 
     // the mimetype
     if (!dir) {
-        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString::fromLatin1("text/plain"));
+        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("text/plain"));
     }
 
     entry.insert(KIO::UDSEntry::UDS_ACCESS, dir ? 0500 : 0400);
@@ -428,7 +428,7 @@ void LDAPProtocol::get(const QUrl &_url)
     }
 
     // tell the mimetype
-    mimeType(QLatin1String("text/plain"));
+    mimeType(QStringLiteral("text/plain"));
     // collect the result
     //QByteArray result;
     filesize_t processed_size = 0;
@@ -446,8 +446,8 @@ void LDAPProtocol::get(const QUrl &_url)
                 QByteArray cookie;
                 int estsize = -1;
                 for (int i = 0; i < mOp.controls().count(); ++i) {
-                    qCDebug(KLDAP_LOG) << " control oid: " << mOp.controls()[i].oid();
-                    estsize = mOp.controls()[i].parsePageControl(cookie);
+                    qCDebug(KLDAP_LOG) << " control oid: " << mOp.controls().at(i).oid();
+                    estsize = mOp.controls().at(i).parsePageControl(cookie);
                     if (estsize != -1) {
                         break;
                     }
@@ -504,7 +504,7 @@ void LDAPProtocol::stat(const QUrl &_url)
 
     // look how many entries match
     saveatt = usrc.attributes();
-    att.append(QLatin1String("dn"));
+    att.append(QStringLiteral("dn"));
 
     if ((id = mOp.search(usrc.dn(), usrc.scope(), usrc.filter(), att)) == -1) {
         LDAPErr();
@@ -530,7 +530,7 @@ void LDAPProtocol::stat(const QUrl &_url)
 
     UDSEntry uds;
     bool critical;
-    LDAPEntry2UDSEntry(usrc.dn(), uds, usrc, usrc.extension(QLatin1String("x-dir"), critical) != QLatin1String("base"));
+    LDAPEntry2UDSEntry(usrc.dn(), uds, usrc, usrc.extension(QStringLiteral("x-dir"), critical) != QLatin1String("base"));
 
     statEntry(uds);
     // we are done
@@ -730,7 +730,7 @@ void LDAPProtocol::listDir(const QUrl &_url)
     QStringList att, saveatt;
     LdapUrl usrc(_url), usrc2;
     bool critical = true;
-    bool isSub = (usrc.extension(QLatin1String("x-dir"), critical) == QLatin1String("sub"));
+    bool isSub = (usrc.extension(QStringLiteral("x-dir"), critical) == QLatin1String("sub"));
 
 //Reactivate it
     //qCDebug(KLDAP_LOG) << "listDir(" << _url << ")";
@@ -745,7 +745,7 @@ void LDAPProtocol::listDir(const QUrl &_url)
     saveatt = usrc.attributes();
     // look up the entries
     if (isSub) {
-        att.append(QLatin1String("dn"));
+        att.append(QStringLiteral("dn"));
         usrc.setAttributes(att);
     }
     if (_url.query().isEmpty()) {
@@ -758,7 +758,7 @@ void LDAPProtocol::listDir(const QUrl &_url)
     }
 
     usrc.setAttributes(QStringList() << QLatin1String(""));
-    usrc.setExtension(QLatin1String("x-dir"), QLatin1String("base"));
+    usrc.setExtension(QStringLiteral("x-dir"), QStringLiteral("base"));
     // publish the results
     UDSEntry uds;
 
